Apis class
A class to handle Razorpay payments with extended options and configurations.
Use this class to open Razorpay Checkout with full control over:
- Currency
- Theme
- Wallets
- Retry behavior
- Custom branding
Extends DevRzpGetway to register callbacks for success, error, and external wallet.
- Inheritance
-
- Object
- DevRzpGetway
- Apis
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onExternalWallet ↔ dynamic Function(ExternalWalletResponse)
-
getter/setter pairinherited
- onPaymentError ↔ dynamic Function(PaymentFailureResponse)
-
getter/setter pairinherited
- onPaymentSuccess ↔ dynamic Function(PaymentSuccessResponse)
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openCheckout(
{required String name, required String email, required String desc, required String phone, required double amount, required String key, required String secret, required int timeout, CurrencyCode currency = CurrencyCode.inr, String? image, Map< String, String> ? notes, bool retryEnabled = true, int retryMaxCount = 1, String? themeColor, List<String> ? externalWallets}) → Future<void> -
Opens Razorpay checkout with advanced options.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited